==> grizzly-http-2.0-b1-sources.jar: org/glassfish/grizzly/http/Method.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly.http;

import java.io.UnsupportedEncodingException;
import org.glassfish.grizzly.http.util.DataChunk;

/**
 * Predefined HTTP methods
 * 
 * @author Alexey Stashok
 */
public enum Method {
    OPTIONS ("OPTIONS"),
    GET ("GET"),
    HEAD ("HEAD"),
    POST ("POST"),
    PUT ("PUT"),
    DELETE ("DELETE"),
    TRACE ("TRACE"),
    CONNECT ("CONNECT");

    public static Method parseDataChunk(final DataChunk methodC) {
        if (methodC.equals(Method.GET.getMethodString())) {
            return Method.GET;
        } else if (methodC.equals(Method.POST.getMethodString())) {
            return Method.POST;
        } else if (methodC.equals(Method.HEAD.getMethodString())) {
            return Method.HEAD;
        } else if (methodC.equals(Method.PUT.getMethodString())) {
            return Method.PUT;
        } else if (methodC.equals(Method.DELETE.getMethodString())) {
            return Method.DELETE;
        } else if (methodC.equals(Method.TRACE.getMethodString())) {
            return Method.TRACE;
        } else if (methodC.equals(Method.CONNECT.getMethodString())) {
            return Method.CONNECT;
        } else if (methodC.equals(Method.OPTIONS.getMethodString())) {
            return Method.OPTIONS;
        } else {
            throw new IllegalStateException("Unknown method " + methodC.toString());
        }
    }

    private final String methodString;
    private byte[] methodBytes;

    private Method(String protocolString) {
        this.methodString = protocolString;
        try {
            this.methodBytes = protocolString.getBytes("US-ASCII");
        } catch (UnsupportedEncodingException ignored) {
            this.methodBytes = protocolString.getBytes();
        }
    }

    public String getMethodString() {
        return methodString;
    }

    public byte[] getMethodBytes() {
        return methodBytes;
    }
}

==> grizzly-http-2.0.1-b2-sources.jar: org/glassfish/grizzly/http/Method.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2010-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.grizzly.http;

import java.io.UnsupportedEncodingException;
import org.glassfish.grizzly.http.util.DataChunk;

/**
 * Predefined HTTP methods
 * 
 * @author Alexey Stashok
 */
public final class Method {
    public static final Method OPTIONS = new Method("OPTIONS");
    public static final Method GET = new Method("GET");
    public static final Method HEAD = new Method("HEAD");
    public static final Method POST = new Method("POST");
    public static final Method PUT = new Method("PUT");
    public static final Method DELETE = new Method("DELETE");
    public static final Method TRACE = new Method("TRACE");
    public static final Method CONNECT = new Method("CONNECT");

    public static Method CUSTOM(final String methodName) {
        return new Method(methodName);
    }

    public static Method parseDataChunk(final DataChunk methodC) {
        if (methodC.equals(Method.GET.getMethodString())) {
            return Method.GET;
        } else if (methodC.equals(Method.POST.getMethodString())) {
            return Method.POST;
        } else if (methodC.equals(Method.HEAD.getMethodString())) {
            return Method.HEAD;
        } else if (methodC.equals(Method.PUT.getMethodString())) {
            return Method.PUT;
        } else if (methodC.equals(Method.DELETE.getMethodString())) {
            return Method.DELETE;
        } else if (methodC.equals(Method.TRACE.getMethodString())) {
            return Method.TRACE;
        } else if (methodC.equals(Method.CONNECT.getMethodString())) {
            return Method.CONNECT;
        } else if (methodC.equals(Method.OPTIONS.getMethodString())) {
            return Method.OPTIONS;
        } else {
            return CUSTOM(methodC.toString());
        }
    }

    private final String methodString;
    private byte[] methodBytes;

    private Method(final String methodString) {
        this.methodString = methodString;
        try {
            this.methodBytes = methodString.getBytes("US-ASCII");
        } catch (UnsupportedEncodingException ignored) {
            this.methodBytes = methodString.getBytes();
        }
    }

    public String getMethodString() {
        return methodString;
    }

    public byte[] getMethodBytes() {
        return methodBytes;
    }
}
